import React, { useState, useEffect } from 'react'
import CartItem from './CartItem.js'
import './shopping-cart.css'
import { useSelector, useDispatch } from 'react-redux'
import { Link } from 'react-router-dom'
import axios from 'axios'

export default function ShoppingCart() {

  const [userSession, setUserSession] = useState(useSelector(state => state.user.currentUser))
  const [allProducts, setAllProducts] = useState(useSelector(state => state.market.products))
  const [cartRefs, setCartRefs] = useState(useSelector(state => state.cart))
  const [cartItems, setCartItems] = useState([])


  // This effect collects the products that are mapped to the cartRefs in the user's cart
  //    and assigns the list of producct-supplemented cart items to the cartItems state
  useEffect(() => {
    const productsFromRefs = []

    cartRefs.map((cartRef) => {
      productsFromRefs.push(({ product: allProducts.filter((currProduct) => (currProduct.sku === cartRef.productRef.sku))[0], quantity: cartRef.quantity }))
    })

    setCartItems(productsFromRefs)

  }, [cartRefs])


  // This function deletes an item from the user's cart
  let handleDelete = (skuToBeDeleted) => {
    console.log("SKU to be deleted: " + skuToBeDeleted)

    const newCartRefs = cartRefs.filter((cartRef) => !(cartRef.productRef.sku === skuToBeDeleted))
    setCartRefs(newCartRefs)

  }

  let updateCart = async () => {

      const cartUpdateObj = {
        userId: userSession.email,
        cartItems: cartRefs
      }

      console.log(JSON.stringify(cartUpdateObj))

      const response = await axios.put(`http://localhost:8080/api/carts/${userSession.email}`, cartUpdateObj)
      return response
  }


  useEffect(() => {

    console.log(updateCart())

  }, [cartItems])

  return (
    <div id="shoppingCartContainer">

      {/* map each cart item into CartItem component */}

      <div id="cartItemList">
        {cartItems.map((currItem) => {
          return (
            <CartItem
              productInfo={currItem.product}
              quantity={currItem.quantity}
              handleDelete={handleDelete}
              key={currItem.product.sku}
            />
          )
        })}
      </div>

      <Link id="checkoutButtonContainer" to="/checkout">
        <button id="checkoutButton">Proceed To Checkout</button>
      </Link>


    </div>
  )
}
